

{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)

A struct that specifies a border around a rectangular area
that can be of different width on each side.
-}

module GI.Gtk.Structs.Border
    ( 

-- * Exported types
    Border(..)                              ,
    newZeroBorder                           ,
    noBorder                                ,


 -- * Methods
-- ** borderCopy
    BorderCopyMethodInfo                    ,
    borderCopy                              ,


-- ** borderFree
    BorderFreeMethodInfo                    ,
    borderFree                              ,


-- ** borderNew
    borderNew                               ,




 -- * Properties
-- ** Bottom
    borderReadBottom                        ,


-- ** Left
    borderReadLeft                          ,


-- ** Right
    borderReadRight                         ,


-- ** Top
    borderReadTop                           ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Gtk.Types
import GI.Gtk.Callbacks

newtype Border = Border (ForeignPtr Border)
foreign import ccall "gtk_border_get_type" c_gtk_border_get_type :: 
    IO GType

instance BoxedObject Border where
    boxedType _ = c_gtk_border_get_type

-- | Construct a `Border` struct initialized to zero.
newZeroBorder :: MonadIO m => m Border
newZeroBorder = liftIO $ callocBoxedBytes 8 >>= wrapBoxed Border

noBorder :: Maybe Border
noBorder = Nothing

borderReadLeft :: Border -> IO Int16
borderReadLeft s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 0) :: IO Int16
    return val

borderReadRight :: Border -> IO Int16
borderReadRight s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 2) :: IO Int16
    return val

borderReadTop :: Border -> IO Int16
borderReadTop s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 4) :: IO Int16
    return val

borderReadBottom :: Border -> IO Int16
borderReadBottom s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 6) :: IO Int16
    return val

-- method Border::new
-- method type : Constructor
-- Args : []
-- Lengths : []
-- returnType : TInterface "Gtk" "Border"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_border_new" gtk_border_new :: 
    IO (Ptr Border)


borderNew ::
    (MonadIO m) =>
    m Border                                -- result
borderNew  = liftIO $ do
    result <- gtk_border_new
    checkUnexpectedReturnNULL "gtk_border_new" result
    result' <- (wrapBoxed Border) result
    return result'

-- method Border::copy
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Gtk" "Border", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : TInterface "Gtk" "Border"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_border_copy" gtk_border_copy :: 
    Ptr Border ->                           -- _obj : TInterface "Gtk" "Border"
    IO (Ptr Border)


borderCopy ::
    (MonadIO m) =>
    Border                                  -- _obj
    -> m Border                             -- result
borderCopy _obj = liftIO $ do
    let _obj' = unsafeManagedPtrGetPtr _obj
    result <- gtk_border_copy _obj'
    checkUnexpectedReturnNULL "gtk_border_copy" result
    result' <- (wrapBoxed Border) result
    touchManagedPtr _obj
    return result'

data BorderCopyMethodInfo
instance (signature ~ (m Border), MonadIO m) => MethodInfo BorderCopyMethodInfo Border signature where
    overloadedMethod _ = borderCopy

-- method Border::free
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Gtk" "Border", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_border_free" gtk_border_free :: 
    Ptr Border ->                           -- _obj : TInterface "Gtk" "Border"
    IO ()


borderFree ::
    (MonadIO m) =>
    Border                                  -- _obj
    -> m ()                                 -- result
borderFree _obj = liftIO $ do
    let _obj' = unsafeManagedPtrGetPtr _obj
    gtk_border_free _obj'
    touchManagedPtr _obj
    return ()

data BorderFreeMethodInfo
instance (signature ~ (m ()), MonadIO m) => MethodInfo BorderFreeMethodInfo Border signature where
    overloadedMethod _ = borderFree

type family ResolveBorderMethod (t :: Symbol) (o :: *) :: * where
    ResolveBorderMethod "copy" o = BorderCopyMethodInfo
    ResolveBorderMethod "free" o = BorderFreeMethodInfo
    ResolveBorderMethod l o = MethodResolutionFailed l o

instance (info ~ ResolveBorderMethod t Border, MethodInfo info Border p) => IsLabelProxy t (Border -> p) where
    fromLabelProxy _ = overloadedMethod (MethodProxy :: MethodProxy info)

#if MIN_VERSION_base(4,9,0)
instance (info ~ ResolveBorderMethod t Border, MethodInfo info Border p) => IsLabel t (Border -> p) where
    fromLabel _ = overloadedMethod (MethodProxy :: MethodProxy info)
#endif


