

{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)

The #GtkTreeIter is the primary structure
for accessing a #GtkTreeModel. Models are expected to put a unique
integer in the @stamp member, and put
model-specific data in the three @user_data
members.
-}

module GI.Gtk.Structs.TreeIter
    ( 

-- * Exported types
    TreeIter(..)                            ,
    newZeroTreeIter                         ,
    noTreeIter                              ,


 -- * Methods
-- ** treeIterCopy
    TreeIterCopyMethodInfo                  ,
    treeIterCopy                            ,


-- ** treeIterFree
    TreeIterFreeMethodInfo                  ,
    treeIterFree                            ,




 -- * Properties
-- ** Stamp
    treeIterReadStamp                       ,


-- ** UserData
    treeIterReadUserData                    ,


-- ** UserData2
    treeIterReadUserData2                   ,


-- ** UserData3
    treeIterReadUserData3                   ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Gtk.Types
import GI.Gtk.Callbacks

newtype TreeIter = TreeIter (ForeignPtr TreeIter)
foreign import ccall "gtk_tree_iter_get_type" c_gtk_tree_iter_get_type :: 
    IO GType

instance BoxedObject TreeIter where
    boxedType _ = c_gtk_tree_iter_get_type

-- | Construct a `TreeIter` struct initialized to zero.
newZeroTreeIter :: MonadIO m => m TreeIter
newZeroTreeIter = liftIO $ callocBoxedBytes 32 >>= wrapBoxed TreeIter

noTreeIter :: Maybe TreeIter
noTreeIter = Nothing

treeIterReadStamp :: TreeIter -> IO Int32
treeIterReadStamp s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 0) :: IO Int32
    return val

treeIterReadUserData :: TreeIter -> IO (Ptr ())
treeIterReadUserData s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 8) :: IO (Ptr ())
    return val

treeIterReadUserData2 :: TreeIter -> IO (Ptr ())
treeIterReadUserData2 s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 16) :: IO (Ptr ())
    return val

treeIterReadUserData3 :: TreeIter -> IO (Ptr ())
treeIterReadUserData3 s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 24) :: IO (Ptr ())
    return val

-- method TreeIter::copy
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Gtk" "TreeIter", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : TInterface "Gtk" "TreeIter"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_tree_iter_copy" gtk_tree_iter_copy :: 
    Ptr TreeIter ->                         -- _obj : TInterface "Gtk" "TreeIter"
    IO (Ptr TreeIter)


treeIterCopy ::
    (MonadIO m) =>
    TreeIter                                -- _obj
    -> m TreeIter                           -- result
treeIterCopy _obj = liftIO $ do
    let _obj' = unsafeManagedPtrGetPtr _obj
    result <- gtk_tree_iter_copy _obj'
    checkUnexpectedReturnNULL "gtk_tree_iter_copy" result
    result' <- (wrapBoxed TreeIter) result
    touchManagedPtr _obj
    return result'

data TreeIterCopyMethodInfo
instance (signature ~ (m TreeIter), MonadIO m) => MethodInfo TreeIterCopyMethodInfo TreeIter signature where
    overloadedMethod _ = treeIterCopy

-- method TreeIter::free
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Gtk" "TreeIter", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_tree_iter_free" gtk_tree_iter_free :: 
    Ptr TreeIter ->                         -- _obj : TInterface "Gtk" "TreeIter"
    IO ()


treeIterFree ::
    (MonadIO m) =>
    TreeIter                                -- _obj
    -> m ()                                 -- result
treeIterFree _obj = liftIO $ do
    let _obj' = unsafeManagedPtrGetPtr _obj
    gtk_tree_iter_free _obj'
    touchManagedPtr _obj
    return ()

data TreeIterFreeMethodInfo
instance (signature ~ (m ()), MonadIO m) => MethodInfo TreeIterFreeMethodInfo TreeIter signature where
    overloadedMethod _ = treeIterFree

type family ResolveTreeIterMethod (t :: Symbol) (o :: *) :: * where
    ResolveTreeIterMethod "copy" o = TreeIterCopyMethodInfo
    ResolveTreeIterMethod "free" o = TreeIterFreeMethodInfo
    ResolveTreeIterMethod l o = MethodResolutionFailed l o

instance (info ~ ResolveTreeIterMethod t TreeIter, MethodInfo info TreeIter p) => IsLabelProxy t (TreeIter -> p) where
    fromLabelProxy _ = overloadedMethod (MethodProxy :: MethodProxy info)

#if MIN_VERSION_base(4,9,0)
instance (info ~ ResolveTreeIterMethod t TreeIter, MethodInfo info TreeIter p) => IsLabel t (TreeIter -> p) where
    fromLabel _ = overloadedMethod (MethodProxy :: MethodProxy info)
#endif


